@@ -58,7 +58,7 @@ def collect(
     frags = scriv.fragments_to_combine()
     if not frags:
         logger.info("No changelog fragments to collect")
-        return
+        sys.exit(2)
 
     changelog = scriv.changelog()
     changelog.read()
@@ -71,6 +71,12 @@ def collect(
                 if etitle is None:
                     continue
                 eversion = Version.from_text(etitle)
+                if eversion is None:
+                    sys.exit(
+                        f"Entry {etitle!r} is not a valid version! "
+                        + "If scriv should ignore this heading, add "
+                        + "'scriv-end-here' somewhere before it."
+                    )
                 if eversion == version:
                     sys.exit(
                         f"Entry {etitle!r} already uses "
